@@ -1,10 +1,10 @@
 /*
     ext2.c -- generic ext2 stuff
-    Copyright (C) 1998, 1999, 2000, 2001 Free Software Foundation, Inc.
-  
+    Copyright (C) 1998, 1999, 2000, 2001, 2007 Free Software Foundation, Inc.
+
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,11 +13,10 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "config.h"
+#include <config.h>
 
 #ifndef DISCOVER_ONLY
 
@@ -781,7 +780,6 @@ struct ext2_fs *ext2_open(struct ext2_dev_handle *handle, int state)
 	fs->metadirty = 0;
 	return fs;
 
-error_free_gd:
 	ped_free(fs->gd);
 error_deinit_bcache:
 	ext2_bcache_deinit(fs);
